.django_instagram_media_wall_item {
    width:  25%; height: auto;
    float: left;
    position: relative
}

.django_instagram_media_wall_item img {
    width: 100%; height: auto;
    float: left
}

.django_instagram_media_wall_item a span {
    position: absolute;
    bottom: 0; left: 0; right: 0;
    color: #F3F3F3; background: #222222; opacity: 0.8;
    z-index: 50
}